# mdformat-recover-urls

用於**恢復**以 `.` 或 `#` 開頭的連結

## 利用

隨 `mdformat` 安裝

```bash
uv tool install mdformat --with mdformat-recover-urls
```

## 開發

```bash
uv sync

uv run pytest ./test.py

uv build
```
